==> huaweicloudsdkdli-3.0.108-py2.py3-none-any.whl: huaweicloudsdkdli/v1/model/create_table_req.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateTableReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'table_name': 'str',
        'data_location': 'str',
        'description': 'str',
        'columns': 'list[CreateTableReqColumn]',
        'select_statement': 'str',
        'data_type': 'str',
        'data_path': 'str',
        'with_column_header': 'bool',
        'delimiter': 'str',
        'quote_char': 'str',
        'escape_char': 'str',
        'date_format': 'str',
        'timestamp_format': 'str'
    }

    attribute_map = {
        'table_name': 'table_name',
        'data_location': 'data_location',
        'description': 'description',
        'columns': 'columns',
        'select_statement': 'select_statement',
        'data_type': 'data_type',
        'data_path': 'data_path',
        'with_column_header': 'with_column_header',
        'delimiter': 'delimiter',
        'quote_char': 'quote_char',
        'escape_char': 'escape_char',
        'date_format': 'date_format',
        'timestamp_format': 'timestamp_format'
    }

    def __init__(self, table_name=None, data_location=None, description=None, columns=None, select_statement=None, data_type=None, data_path=None, with_column_header=None, delimiter=None, quote_char=None, escape_char=None, date_format=None, timestamp_format=None):
        """CreateTableReq

        The model defined in huaweicloud sdk

        :param table_name: 新增表名称。
        :type table_name: str
        :param data_location: 数据存储的地方，分OBS表和DLI表。
        :type data_location: str
        :param description: 新增表的描述信息。
        :type description: str
        :param columns: 新增表的列。
        :type columns: list[:class:`huaweicloudsdkdli.v1.CreateTableReqColumn`]
        :param select_statement: 创建视图时依赖的查找语句。查找语句中的表需要附加所属数据库，即 “数据库.数据表”格式。data_location为VIEW时填写。
        :type select_statement: str
        :param data_type: OBS表必选参数。新增OBS表数据的类型，目前支持：Parquet、ORC、CSV、JSON、Carbon和Avro格式。
        :type data_type: str
        :param data_path: OBS表必选参数。新增OBS表数据的存储路径，必须是OBS上的路径，以s3a开头。
        :type data_path: str
        :param with_column_header: OBS表非必选参数。OBS表数据是否包含表头。只有CSV类型数据具有该属性。
        :type with_column_header: bool
        :param delimiter: OBS表非必选参数。用户自定义数据分隔符。只有CSV类型数据具有该属性。
        :type delimiter: str
        :param quote_char: OBS表非必选参数。用户自定义引用字符，默认为双引号（即“\\\&quot;”）。只有CSV类型数据具有该属性。
        :type quote_char: str
        :param escape_char: OBS表非必选参数。用户自定义转义字符，默认为反斜杠（即\&quot;\\\\\&quot;）。只有CSV类型数据具有该属性。
        :type escape_char: str
        :param date_format: OBS表非必选参数。用户自定义日期类型，默认格式为“yyyy-MM-dd”。只有CSV和JSON类型数据具有该属性。
        :type date_format: str
        :param timestamp_format: OBS表非必选参数。用户自定义时间类型。默认格式为“yyyy-MM-dd HH:mm:ss”。只有CSV和JSON类型数据具有该属性。
        :type timestamp_format: str
        """
        
        

        self._table_name = None
        self._data_location = None
        self._description = None
        self._columns = None
        self._select_statement = None
        self._data_type = None
        self._data_path = None
        self._with_column_header = None
        self._delimiter = None
        self._quote_char = None
        self._escape_char = None
        self._date_format = None
        self._timestamp_format = None
        self.discriminator = None

        self.table_name = table_name
        self.data_location = data_location
        if description is not None:
            self.description = description
        self.columns = columns
        if select_statement is not None:
            self.select_statement = select_statement
        if data_type is not None:
            self.data_type = data_type
        if data_path is not None:
            self.data_path = data_path
        if with_column_header is not None:
            self.with_column_header = with_column_header
        if delimiter is not None:
            self.delimiter = delimiter
        if quote_char is not None:
            self.quote_char = quote_char
        if escape_char is not None:
            self.escape_char = escape_char
        if date_format is not None:
            self.date_format = date_format
        if timestamp_format is not None:
            self.timestamp_format = timestamp_format

    @property
    def table_name(self):
        """Gets the table_name of this CreateTableReq.

        新增表名称。

        :return: The table_name of this CreateTableReq.
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """Sets the table_name of this CreateTableReq.

        新增表名称。

        :param table_name: The table_name of this CreateTableReq.
        :type table_name: str
        """
        self._table_name = table_name

    @property
    def data_location(self):
        """Gets the data_location of this CreateTableReq.

        数据存储的地方，分OBS表和DLI表。

        :return: The data_location of this CreateTableReq.
        :rtype: str
        """
        return self._data_location

    @data_location.setter
    def data_location(self, data_location):
        """Sets the data_location of this CreateTableReq.

        数据存储的地方，分OBS表和DLI表。

        :param data_location: The data_location of this CreateTableReq.
        :type data_location: str
        """
        self._data_location = data_location

    @property
    def description(self):
        """Gets the description of this CreateTableReq.

        新增表的描述信息。

        :return: The description of this CreateTableReq.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateTableReq.

        新增表的描述信息。

        :param description: The description of this CreateTableReq.
        :type description: str
        """
        self._description = description

    @property
    def columns(self):
        """Gets the columns of this CreateTableReq.

        新增表的列。

        :return: The columns of this CreateTableReq.
        :rtype: list[:class:`huaweicloudsdkdli.v1.CreateTableReqColumn`]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """Sets the columns of this CreateTableReq.

        新增表的列。

        :param columns: The columns of this CreateTableReq.
        :type columns: list[:class:`huaweicloudsdkdli.v1.CreateTableReqColumn`]
        """
        self._columns = columns

    @property
    def select_statement(self):
        """Gets the select_statement of this CreateTableReq.

        创建视图时依赖的查找语句。查找语句中的表需要附加所属数据库，即 “数据库.数据表”格式。data_location为VIEW时填写。

        :return: The select_statement of this CreateTableReq.
        :rtype: str
        """
        return self._select_statement

    @select_statement.setter
    def select_statement(self, select_statement):
        """Sets the select_statement of this CreateTableReq.

        创建视图时依赖的查找语句。查找语句中的表需要附加所属数据库，即 “数据库.数据表”格式。data_location为VIEW时填写。

        :param select_statement: The select_statement of this CreateTableReq.
        :type select_statement: str
        """
        self._select_statement = select_statement

    @property
    def data_type(self):
        """Gets the data_type of this CreateTableReq.

        OBS表必选参数。新增OBS表数据的类型，目前支持：Parquet、ORC、CSV、JSON、Carbon和Avro格式。

        :return: The data_type of this CreateTableReq.
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this CreateTableReq.

        OBS表必选参数。新增OBS表数据的类型，目前支持：Parquet、ORC、CSV、JSON、Carbon和Avro格式。

        :param data_type: The data_type of this CreateTableReq.
        :type data_type: str
        """
        self._data_type = data_type

    @property
    def data_path(self):
        """Gets the data_path of this CreateTableReq.

        OBS表必选参数。新增OBS表数据的存储路径，必须是OBS上的路径，以s3a开头。

        :return: The data_path of this CreateTableReq.
        :rtype: str
        """
        return self._data_path

    @data_path.setter
    def data_path(self, data_path):
        """Sets the data_path of this CreateTableReq.

        OBS表必选参数。新增OBS表数据的存储路径，必须是OBS上的路径，以s3a开头。

        :param data_path: The data_path of this CreateTableReq.
        :type data_path: str
        """
        self._data_path = data_path

    @property
    def with_column_header(self):
        """Gets the with_column_header of this CreateTableReq.

        OBS表非必选参数。OBS表数据是否包含表头。只有CSV类型数据具有该属性。

        :return: The with_column_header of this CreateTableReq.
        :rtype: bool
        """
        return self._with_column_header

    @with_column_header.setter
    def with_column_header(self, with_column_header):
        """Sets the with_column_header of this CreateTableReq.

        OBS表非必选参数。OBS表数据是否包含表头。只有CSV类型数据具有该属性。

        :param with_column_header: The with_column_header of this CreateTableReq.
        :type with_column_header: bool
        """
        self._with_column_header = with_column_header

    @property
    def delimiter(self):
        """Gets the delimiter of this CreateTableReq.

        OBS表非必选参数。用户自定义数据分隔符。只有CSV类型数据具有该属性。

        :return: The delimiter of this CreateTableReq.
        :rtype: str
        """
        return self._delimiter

    @delimiter.setter
    def delimiter(self, delimiter):
        """Sets the delimiter of this CreateTableReq.

        OBS表非必选参数。用户自定义数据分隔符。只有CSV类型数据具有该属性。

        :param delimiter: The delimiter of this CreateTableReq.
        :type delimiter: str
        """
        self._delimiter = delimiter

    @property
    def quote_char(self):
        """Gets the quote_char of this CreateTableReq.

        OBS表非必选参数。用户自定义引用字符，默认为双引号（即“\\\"”）。只有CSV类型数据具有该属性。

        :return: The quote_char of this CreateTableReq.
        :rtype: str
        """
        return self._quote_char

    @quote_char.setter
    def quote_char(self, quote_char):
        """Sets the quote_char of this CreateTableReq.

        OBS表非必选参数。用户自定义引用字符，默认为双引号（即“\\\"”）。只有CSV类型数据具有该属性。

        :param quote_char: The quote_char of this CreateTableReq.
        :type quote_char: str
        """
        self._quote_char = quote_char

    @property
    def escape_char(self):
        """Gets the escape_char of this CreateTableReq.

        OBS表非必选参数。用户自定义转义字符，默认为反斜杠（即\"\\\\\"）。只有CSV类型数据具有该属性。

        :return: The escape_char of this CreateTableReq.
        :rtype: str
        """
        return self._escape_char

    @escape_char.setter
    def escape_char(self, escape_char):
        """Sets the escape_char of this CreateTableReq.

        OBS表非必选参数。用户自定义转义字符，默认为反斜杠（即\"\\\\\"）。只有CSV类型数据具有该属性。

        :param escape_char: The escape_char of this CreateTableReq.
        :type escape_char: str
        """
        self._escape_char = escape_char

    @property
    def date_format(self):
        """Gets the date_format of this CreateTableReq.

        OBS表非必选参数。用户自定义日期类型，默认格式为“yyyy-MM-dd”。只有CSV和JSON类型数据具有该属性。

        :return: The date_format of this CreateTableReq.
        :rtype: str
        """
        return self._date_format

    @date_format.setter
    def date_format(self, date_format):
        """Sets the date_format of this CreateTableReq.

        OBS表非必选参数。用户自定义日期类型，默认格式为“yyyy-MM-dd”。只有CSV和JSON类型数据具有该属性。

        :param date_format: The date_format of this CreateTableReq.
        :type date_format: str
        """
        self._date_format = date_format

    @property
    def timestamp_format(self):
        """Gets the timestamp_format of this CreateTableReq.

        OBS表非必选参数。用户自定义时间类型。默认格式为“yyyy-MM-dd HH:mm:ss”。只有CSV和JSON类型数据具有该属性。

        :return: The timestamp_format of this CreateTableReq.
        :rtype: str
        """
        return self._timestamp_format

    @timestamp_format.setter
    def timestamp_format(self, timestamp_format):
        """Sets the timestamp_format of this CreateTableReq.

        OBS表非必选参数。用户自定义时间类型。默认格式为“yyyy-MM-dd HH:mm:ss”。只有CSV和JSON类型数据具有该属性。

        :param timestamp_format: The timestamp_format of this CreateTableReq.
        :type timestamp_format: str
        """
        self._timestamp_format = timestamp_format

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateTableReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdli-3.1.1-py2.py3-none-any.whl: huaweicloudsdkdli/v1/model/create_table_req.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateTableReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'table_name': 'str',
        'data_location': 'str',
        'description': 'str',
        'columns': 'list[CreateTableReqColumn]',
        'data_type': 'str',
        'data_path': 'str',
        'with_column_header': 'bool',
        'delimiter': 'str',
        'quote_char': 'str',
        'escape_char': 'str',
        'date_format': 'str',
        'timestamp_format': 'str',
        'select_statement': 'str'
    }

    attribute_map = {
        'table_name': 'table_name',
        'data_location': 'data_location',
        'description': 'description',
        'columns': 'columns',
        'data_type': 'data_type',
        'data_path': 'data_path',
        'with_column_header': 'with_column_header',
        'delimiter': 'delimiter',
        'quote_char': 'quote_char',
        'escape_char': 'escape_char',
        'date_format': 'date_format',
        'timestamp_format': 'timestamp_format',
        'select_statement': 'select_statement'
    }

    def __init__(self, table_name=None, data_location=None, description=None, columns=None, data_type=None, data_path=None, with_column_header=None, delimiter=None, quote_char=None, escape_char=None, date_format=None, timestamp_format=None, select_statement=None):
        """CreateTableReq

        The model defined in huaweicloud sdk

        :param table_name: 新增表名称。
        :type table_name: str
        :param data_location: 数据存储的地方，分VIEW视图，OBS表和DLI表。
        :type data_location: str
        :param description: 新增表的描述信息。
        :type description: str
        :param columns: OBS表和DLI表必选参数。新增表的列。
        :type columns: list[:class:`huaweicloudsdkdli.v1.CreateTableReqColumn`]
        :param data_type: OBS表必选参数。新增OBS表数据的类型，目前支持：Parquet、ORC、CSV、JSON、Carbon和Avro格式。
        :type data_type: str
        :param data_path: OBS表必选参数。新增OBS表数据的存储路径，必须是OBS上的路径，以s3a开头。
        :type data_path: str
        :param with_column_header: OBS表非必选参数。OBS表数据是否包含表头。只有CSV类型数据具有该属性。
        :type with_column_header: bool
        :param delimiter: OBS表非必选参数。用户自定义数据分隔符。只有CSV类型数据具有该属性。
        :type delimiter: str
        :param quote_char: OBS表非必选参数。用户自定义引用字符，默认为双引号（即“\\\&quot;”）。只有CSV类型数据具有该属性。
        :type quote_char: str
        :param escape_char: OBS表非必选参数。用户自定义转义字符，默认为反斜杠（即\&quot;\\\\\&quot;）。只有CSV类型数据具有该属性。
        :type escape_char: str
        :param date_format: OBS表非必选参数。用户自定义日期类型，默认格式为“yyyy-MM-dd”。只有CSV和JSON类型数据具有该属性。
        :type date_format: str
        :param timestamp_format: OBS表非必选参数。用户自定义时间类型。默认格式为“yyyy-MM-dd HH:mm:ss”。只有CSV和JSON类型数据具有该属性。
        :type timestamp_format: str
        :param select_statement: VIEW视图必选参数，创建视图时的数据选择语句。语句中涉及表需要使用“表&#x3D;库名.表名”的格式
        :type select_statement: str
        """
        
        

        self._table_name = None
        self._data_location = None
        self._description = None
        self._columns = None
        self._data_type = None
        self._data_path = None
        self._with_column_header = None
        self._delimiter = None
        self._quote_char = None
        self._escape_char = None
        self._date_format = None
        self._timestamp_format = None
        self._select_statement = None
        self.discriminator = None

        self.table_name = table_name
        self.data_location = data_location
        if description is not None:
            self.description = description
        self.columns = columns
        if data_type is not None:
            self.data_type = data_type
        if data_path is not None:
            self.data_path = data_path
        if with_column_header is not None:
            self.with_column_header = with_column_header
        if delimiter is not None:
            self.delimiter = delimiter
        if quote_char is not None:
            self.quote_char = quote_char
        if escape_char is not None:
            self.escape_char = escape_char
        if date_format is not None:
            self.date_format = date_format
        if timestamp_format is not None:
            self.timestamp_format = timestamp_format
        if select_statement is not None:
            self.select_statement = select_statement

    @property
    def table_name(self):
        """Gets the table_name of this CreateTableReq.

        新增表名称。

        :return: The table_name of this CreateTableReq.
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """Sets the table_name of this CreateTableReq.

        新增表名称。

        :param table_name: The table_name of this CreateTableReq.
        :type table_name: str
        """
        self._table_name = table_name

    @property
    def data_location(self):
        """Gets the data_location of this CreateTableReq.

        数据存储的地方，分VIEW视图，OBS表和DLI表。

        :return: The data_location of this CreateTableReq.
        :rtype: str
        """
        return self._data_location

    @data_location.setter
    def data_location(self, data_location):
        """Sets the data_location of this CreateTableReq.

        数据存储的地方，分VIEW视图，OBS表和DLI表。

        :param data_location: The data_location of this CreateTableReq.
        :type data_location: str
        """
        self._data_location = data_location

    @property
    def description(self):
        """Gets the description of this CreateTableReq.

        新增表的描述信息。

        :return: The description of this CreateTableReq.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateTableReq.

        新增表的描述信息。

        :param description: The description of this CreateTableReq.
        :type description: str
        """
        self._description = description

    @property
    def columns(self):
        """Gets the columns of this CreateTableReq.

        OBS表和DLI表必选参数。新增表的列。

        :return: The columns of this CreateTableReq.
        :rtype: list[:class:`huaweicloudsdkdli.v1.CreateTableReqColumn`]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """Sets the columns of this CreateTableReq.

        OBS表和DLI表必选参数。新增表的列。

        :param columns: The columns of this CreateTableReq.
        :type columns: list[:class:`huaweicloudsdkdli.v1.CreateTableReqColumn`]
        """
        self._columns = columns

    @property
    def data_type(self):
        """Gets the data_type of this CreateTableReq.

        OBS表必选参数。新增OBS表数据的类型，目前支持：Parquet、ORC、CSV、JSON、Carbon和Avro格式。

        :return: The data_type of this CreateTableReq.
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this CreateTableReq.

        OBS表必选参数。新增OBS表数据的类型，目前支持：Parquet、ORC、CSV、JSON、Carbon和Avro格式。

        :param data_type: The data_type of this CreateTableReq.
        :type data_type: str
        """
        self._data_type = data_type

    @property
    def data_path(self):
        """Gets the data_path of this CreateTableReq.

        OBS表必选参数。新增OBS表数据的存储路径，必须是OBS上的路径，以s3a开头。

        :return: The data_path of this CreateTableReq.
        :rtype: str
        """
        return self._data_path

    @data_path.setter
    def data_path(self, data_path):
        """Sets the data_path of this CreateTableReq.

        OBS表必选参数。新增OBS表数据的存储路径，必须是OBS上的路径，以s3a开头。

        :param data_path: The data_path of this CreateTableReq.
        :type data_path: str
        """
        self._data_path = data_path

    @property
    def with_column_header(self):
        """Gets the with_column_header of this CreateTableReq.

        OBS表非必选参数。OBS表数据是否包含表头。只有CSV类型数据具有该属性。

        :return: The with_column_header of this CreateTableReq.
        :rtype: bool
        """
        return self._with_column_header

    @with_column_header.setter
    def with_column_header(self, with_column_header):
        """Sets the with_column_header of this CreateTableReq.

        OBS表非必选参数。OBS表数据是否包含表头。只有CSV类型数据具有该属性。

        :param with_column_header: The with_column_header of this CreateTableReq.
        :type with_column_header: bool
        """
        self._with_column_header = with_column_header

    @property
    def delimiter(self):
        """Gets the delimiter of this CreateTableReq.

        OBS表非必选参数。用户自定义数据分隔符。只有CSV类型数据具有该属性。

        :return: The delimiter of this CreateTableReq.
        :rtype: str
        """
        return self._delimiter

    @delimiter.setter
    def delimiter(self, delimiter):
        """Sets the delimiter of this CreateTableReq.

        OBS表非必选参数。用户自定义数据分隔符。只有CSV类型数据具有该属性。

        :param delimiter: The delimiter of this CreateTableReq.
        :type delimiter: str
        """
        self._delimiter = delimiter

    @property
    def quote_char(self):
        """Gets the quote_char of this CreateTableReq.

        OBS表非必选参数。用户自定义引用字符，默认为双引号（即“\\\"”）。只有CSV类型数据具有该属性。

        :return: The quote_char of this CreateTableReq.
        :rtype: str
        """
        return self._quote_char

    @quote_char.setter
    def quote_char(self, quote_char):
        """Sets the quote_char of this CreateTableReq.

        OBS表非必选参数。用户自定义引用字符，默认为双引号（即“\\\"”）。只有CSV类型数据具有该属性。

        :param quote_char: The quote_char of this CreateTableReq.
        :type quote_char: str
        """
        self._quote_char = quote_char

    @property
    def escape_char(self):
        """Gets the escape_char of this CreateTableReq.

        OBS表非必选参数。用户自定义转义字符，默认为反斜杠（即\"\\\\\"）。只有CSV类型数据具有该属性。

        :return: The escape_char of this CreateTableReq.
        :rtype: str
        """
        return self._escape_char

    @escape_char.setter
    def escape_char(self, escape_char):
        """Sets the escape_char of this CreateTableReq.

        OBS表非必选参数。用户自定义转义字符，默认为反斜杠（即\"\\\\\"）。只有CSV类型数据具有该属性。

        :param escape_char: The escape_char of this CreateTableReq.
        :type escape_char: str
        """
        self._escape_char = escape_char

    @property
    def date_format(self):
        """Gets the date_format of this CreateTableReq.

        OBS表非必选参数。用户自定义日期类型，默认格式为“yyyy-MM-dd”。只有CSV和JSON类型数据具有该属性。

        :return: The date_format of this CreateTableReq.
        :rtype: str
        """
        return self._date_format

    @date_format.setter
    def date_format(self, date_format):
        """Sets the date_format of this CreateTableReq.

        OBS表非必选参数。用户自定义日期类型，默认格式为“yyyy-MM-dd”。只有CSV和JSON类型数据具有该属性。

        :param date_format: The date_format of this CreateTableReq.
        :type date_format: str
        """
        self._date_format = date_format

    @property
    def timestamp_format(self):
        """Gets the timestamp_format of this CreateTableReq.

        OBS表非必选参数。用户自定义时间类型。默认格式为“yyyy-MM-dd HH:mm:ss”。只有CSV和JSON类型数据具有该属性。

        :return: The timestamp_format of this CreateTableReq.
        :rtype: str
        """
        return self._timestamp_format

    @timestamp_format.setter
    def timestamp_format(self, timestamp_format):
        """Sets the timestamp_format of this CreateTableReq.

        OBS表非必选参数。用户自定义时间类型。默认格式为“yyyy-MM-dd HH:mm:ss”。只有CSV和JSON类型数据具有该属性。

        :param timestamp_format: The timestamp_format of this CreateTableReq.
        :type timestamp_format: str
        """
        self._timestamp_format = timestamp_format

    @property
    def select_statement(self):
        """Gets the select_statement of this CreateTableReq.

        VIEW视图必选参数，创建视图时的数据选择语句。语句中涉及表需要使用“表=库名.表名”的格式

        :return: The select_statement of this CreateTableReq.
        :rtype: str
        """
        return self._select_statement

    @select_statement.setter
    def select_statement(self, select_statement):
        """Sets the select_statement of this CreateTableReq.

        VIEW视图必选参数，创建视图时的数据选择语句。语句中涉及表需要使用“表=库名.表名”的格式

        :param select_statement: The select_statement of this CreateTableReq.
        :type select_statement: str
        """
        self._select_statement = select_statement

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateTableReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
